/*
    Copyright (C) 1995-1998 AROS - The Amiga Research OS
    $Id: setconsoletask.c,v 1.1.1.1 2005/03/15 15:54:40 laire Exp $

    Desc: Set the console handler for the current process.
    Lang: english
*/
#include "dos_intern.h"
#include <proto/exec.h>

/*****************************************************************************

    NAME */
#include <dos/dosextens.h>
#include <proto/dos.h>

	AROS_LH1(struct MsgPort *, SetConsoleTask,

/*  SYNOPSIS */
	AROS_LHA(struct MsgPort *, handler, D1),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 86, Dos)

/*  FUNCTION
	Set the console handler for the current process, and return the
	old handler.

    INPUTS
	handler		- The new console handler for the process.

    RESULT
	The address of the old handler.

    NOTES
	The use of Task in the name is because historically filesystem
	handlers were tasks (instead of Devices).

    EXAMPLE

    BUGS

    SEE ALSO
	GetConsoleTask()

    INTERNALS

    HISTORY
	27-11-96    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    APTR old;
    struct Process *me = (struct Process *)FindTask(NULL);

    DEBUG_ACCESSOR(dprintf("SetConsoleTask: me = $%lx, new = $%lx, old = $%lx\n",
			   me, handler, me->pr_Task.tc_Node.ln_Type == NT_PROCESS ? me->pr_ConsoleTask : NULL));

    FAILFORTASK(me, return NULL;)

    old = me->pr_ConsoleTask;
    me->pr_ConsoleTask = handler;
    return old;

    AROS_LIBFUNC_EXIT
} /* SetConsoleTask */
